#set -x
#=========================================================================
# Copyright (C) VMware, Inc. 1986-2011.  All Rights Reserved.
#
# Name - misc.sh
#
# Purpose - set up various useful functions and defaults for scripts
#
# $Id: misc.hp.sh 26311 2011-08-01 22:42:15Z stever $
#
#=========================================================================

EXEEXT=
if [ -d /opt/gemstone ]; then
  GEMSTONE_LOCKBASE=/opt/gemstone
elif [ -d /usr/gemstone ]; then
  GEMSTONE_LOCKBASE=/usr/gemstone
else
  GEMSTONE_LOCKBASE=/opt/gemstone
fi
GEMSTONE_LOCKEXT="..LCK"                 # lock dir file extention
GEMSTONE_LOCKDIR="$GEMSTONE_LOCKBASE/locks"
NULLDEV=/dev/null
RM=/bin/rm
LS=/bin/ls
GSTMP=/tmp

GEMSTONE_LOGDIR="$GEMSTONE_LOCKBASE/log"          #   required log directory
GEMSTONE_VERSION=24

# first argument is the switch passed, second is string to print
giveHelp() {
  # Make sure user has decent pager...
  if [ "x$PAGER" = "x" ]; then
    PAGER=more
  fi
  # Preferred help command is "-h."  Support "-H" and "help" for compatibility.
  if [ "x$1" = "x-h" ] || [ "x$1" = "x-H" ] || [ "x$1" = "xhelp" ]; then
    echo "Usage: $2 "
    exit 0
  fi
}

# error control
defaultErrorControl() {
  trap 'echo "${comid}[Error]:   ^C termination."; exit 1' 2	# SIGINT
  trap 'echo "${comid}[Error]:   kill termination."; exit 1' 15	# SIGTERM
  trap '' 1 					# SIGHUP
}

# switch procesing
# echo "in misc.sh SCRIPTDIR = $SCRIPTDIR" # enable for debugging
getSwitches() {
  #  echo "in getSwitches SCRIPTDIR = $SCRIPTDIR"  # enable for debugging
  unset _POSIX_OPTION_ORDER # Disable queer getopt mode
  switches="`$GEMSTONE/bin/ggetopt $1 $2`"
  status=$?
  if [ $status -ne 0 ]; then
    # ggetopt error
    echo "${comid}[Error]:   ggetopt error"
    exit 1
  fi
}

# Put descriptor limit back!
returnDescriptors() {
  if [ $hasDescCmd = y ]; then
    ulimit -n $originalDescriptorLimit
  fi
}

requireDirs() {
  for directory in $*
  do
    if [ ! -d $directory ]; then
      echo "${comid}[Error]:   required directory $directory is missing."
      exit 1
    fi
  done
}

requireExes() {
  for file in $*
  do
    if [ ! -x $file$EXEEXT ]; then
      echo "${comid}[Error]:   cannot execute file $file$EXEEXT "
      exit 1
    fi
  done
}

simpleNRS () {
  # we must have a name - i.e. !tcp!name
  if [ "x$nrbody" = "x" ]; then
    # no name given
    echo "${comid}[Error]:       can not determine name part of the gemStoneName NRSpec."
    exit 1
  fi 

  # name must not include spaces or tabs
  spaceindex=`expr "$nrbody" : '.* .*'`
  tabindex=`expr "$nrbody" : '.*	.*'`
  if [ $spaceindex -ne 0 ] || [ $tabindex -ne 0 ]; then
    echo "${comid}[Error]: name part of netLdiName $nrbody has white space."
    exit 1
  fi

  # name must NOT be a filespec or path 
  stoneName_first_char=`expr "$nrbody" : '^\(.\).*$'`
  if [ "x$stoneName_first_char" = "x/" ]; then
    echo "${comid}[Error]:    name part of gemStoneName $nrbody must not be a path."
    exit 1 
  fi

  # the task type must be "" or "server"
  if [ "$nrexplicit" = "y" ] && [ "x$nrtaskname" != "x" ]; then
    if [ "$nrtaskname" != "server" ]; then
      echo "${comid}[Error]:    $nrtaskname , invalid gemStoneName NRSpec modifier."
      exit 1 
    fi
  fi

  # tcp or TCP protocol only! for now
  if [ "x$nrprotocol" = "x" ]; then nrprotocol="$default_protocol"; fi
  if [ "$nrprotocol" != "tcp" ] && [ "$nrprotocol" != "TCP" ]; then
    echo "${comid}[Error]:    $nrprotocol network protocol is not recognized."
    exit 1
  fi
}

# initialize arguments used for setconfig...
initConfig() {
  systemConfig=""
  exeConfig="$1"
  netLdiSpec=""
  runpgsvrSpec=""
}

##############################################################################
# Platform specific stuff follows...
# This file is specific for hppa.hpux only!!
##############################################################################

HOSTTYPE=hppa
export HOSTTYPE
OSTYPE=hpux
export OSTYPE
vendor="Hewlett-Packard"
PING=/etc/ping
pingArgs=""
pingPostArgs="64 1"

# raise file descriptors, i.e., just before calling executable
# saves old descriptor limit in originalDescriptorLimit
# no effect on HPUX!!
raiseDescriptors() {
  hasDescCmd=n
  descriptorLimit=32
  originalDescriptorLimit=32
}

getSwapPgm() {
  if [ $myEffectiveUid -eq 0 ]; then
    swapPgm=/etc/swapinfo
    if [ ! -x $swapPgm ]; then
      swapPgm=/usr/sam/bin/swapinfo # Alternative location (on pre-8.07 systems)
    fi
  else
    echo "Warning:  unable to verify swap space."
    echo "We would like to find out the amount of swap space you currently have"
    echo "configured, using the swapinfo(1M) program. Unfortunately, this program"
    echo "needs to be run as super-user, and, as far as I can tell, you do not"
    echo "currently have super-user privileges."
    echo "A minimal GemStone system will require approximately 20MB of swap."

    swapPgm=gobblegobble            # Turkey sounds
  fi
}

getSwapSize() {
  theSize=`$swapPgm -q`
}

getTabSize() {
  tabSize=skip
}

getAioRequired() {
  requiresRaw=y
  exampleDevice=/dev/rdsk/c4d0s2
  if [ $myEffectiveUid -ne 0 ]; then
    # Must be root in order to use async i/o on the HP
    # installgs.aioNotRoot
    echo "WARNING:  Since you are not running as root, it is not possible to confirm"
    echo "that asynchronous disk transfers are correctly installed.  You may wish to"
    echo "run this program again as root to confirm that your kernel is correctly"
    echo "configured."

    echo "[press return to continue]"
    read prompt
    pgmName=
  fi
}
